@@ -3,9 +3,9 @@ import re
 from difflib import SequenceMatcher
 from dicts import *
 #from .dicts import *
-from morpholog import Morpholog
+import pymorphy2
 
-morph = Morpholog()
+morph = pymorphy2.MorphAnalyzer()
 
 
 # Approximate string matching in array
